@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-$VERSION = '0.5';
+$VERSION = '0.6';
 
 #------------------------------------------------------------------------------
 #
@@ -132,10 +132,9 @@ BEGIN {
 sub get_divs
 {
     my $this = shift;
-    # array to save divs in
     my @divs = ();
        
-    # iterate though my children ...
+    # iterate children ...
     foreach my $node_ref ($this->content_refs_list) 
     {
 	if(ref $$node_ref)
@@ -157,14 +156,47 @@ sub get_divs
 		} 
 	    }
 	    elsif($tag !~ /^img/i &&
-		  $tag !~ /^br/i)
+		  $tag !~ /^br/i &&
+		  $tag !~ /^h/i &&
+		  $tag !~ /script/i &&
+		  $tag !~ /^noembed/i)
 	    {
 		my @contenu=get_paragraphs($$node_ref);
 		if(@contenu)
 		{
-		    push @divs,"<$tag>";
+		    my $balise=$tag;
+		     if ( $tag =~ /^(ol|ul|dl)$/i )
+		    {
+			$balise="list";
+		    }
+		    
+		    else
+		    {
+			
+			if ( $tag =~ /^(li|dt)/i )
+			{
+			    $balise="item";
+			}
+			
+			elsif ($tag =~ /^dd/i )
+			{
+			    $balise="desc";
+			   			    
+			}
+			elsif ($tag =~ /^tr/i )
+			{
+			    $balise="row";
+			   			    
+			}
+			elsif ($tag =~ /^td/i )
+			{
+			    $balise="cell";
+			   			    
+			}
+		    }
+		    push @divs,"<$balise>";
 		    push @divs,@contenu;
-		    push @divs,"</$tag>";
+		    push @divs,"</$balise>";
 		}	
 	    }
 	}
@@ -198,7 +230,9 @@ sub get_paragraphs
 	{
 	    my $tag = $$node_ref->tag;
 	    if($tag !~ /^a$/i &&
-	       $tag !~ /^img$/i)
+	       $tag !~ /^img$/i &&
+	       $tag !~ /script$/i&&
+	       $tag !~ /^noembed/i)
 	    {
 		my @contenu=get_paragraphs($$node_ref);
 		if(@contenu)
@@ -239,7 +273,8 @@ sub get_paragraphs
 		
 		    }
 		    if($balise !~ /^b$/i &&
-		       $balise !~ /^font$/i)
+		       $balise !~ /^font$/i &&
+		       $balise !~ /^h$/i)
 		    {
 			push @paras,"<$balise>";
 			push @paras,@contenu;
@@ -288,8 +323,11 @@ sub get_paragraphs
 # Main
 #
 #------------------------------------------------------------------------------
+
 my $input = join( '', <> );
 my @doc=();
+
+
 eval{
 $html_tree->parse($input);
 };
@@ -317,6 +355,7 @@ foreach my $node_ref ($html_tree->content_refs_list)
 	    $tag =~ /div/i)
     {
 	push @doc,"<?xml version=\"1.0\" encoding=\"ISO-8859-1\" standalone=\"yes\"?>";
+	push @doc,"<page>";
 	push @doc,"<div name=\"$tag\">";
 	
 	if( my @div=get_divs($$node_ref))
@@ -331,6 +370,7 @@ foreach my $node_ref ($html_tree->content_refs_list)
 	    
 	}
 	push @doc,"</div>"; 
+	push @doc,"</page>"; 
 	
     }   
     while (@doc)
